<?php
// config/config.php - Configuration File

define('DB_HOST', 'localhost');
define('DB_USER', 'sharings_aleee_ahmed');
define('DB_PASSWORD', 'unlockme109901');
define('DB_NAME', 'sharings_admob_manager');

// Google OAuth Configuration
define('GOOGLE_CLIENT_ID', '395187581258-2hkt6kbglll5bl02t2ff1dpkaq213vgv.apps.googleusercontent.com');
define('GOOGLE_CLIENT_SECRET', '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');
define('GOOGLE_REDIRECT_URI', 'https://musicplayer.sharingsapp.com/admob-manager/callback.php');

// AdMob API Configuration
define('ADMOB_API_VERSION', 'v1');
define('ADMOB_API_ENDPOINT', 'https://admobapi.googleapis.com');

// App Settings
define('APP_NAME', 'AdMob API Manager');
define('APP_URL', 'https://musicplayer.sharingsapp.com/admob-manager/');
define('CACHE_DURATION', 3600); // 1 hour in seconds
define('SESSION_TIMEOUT', 7200); // 2 hours

// Debug Mode
define('DEBUG_MODE', true);
define('LOG_PATH', __DIR__ . '/../logs/');

// Create logs directory if it doesn't exist
if (!is_dir(LOG_PATH)) {
    mkdir(LOG_PATH, 0755, true);
}

// Error Reporting
if (DEBUG_MODE) {
    error_reporting(E_ALL);
    ini_set('display_errors', 1);
} else {
    error_reporting(0);
    ini_set('display_errors', 0);
}

?>