<?php
// includes/sidebar.php
?>
<aside class="sidebar">
    <div class="sidebar-header">
        <h2><i class="fas fa-chart-line"></i> AdMob Manager</h2>
    </div>
    
    <nav class="sidebar-nav">
        <a href="/admob-manager/pages/dashboard.php" class="nav-item <?php echo basename($_SERVER['PHP_SELF']) == 'dashboard.php' ? 'active' : ''; ?>">
            <i class="fas fa-home"></i>
            <span>Dashboard</span>
        </a>
        
        <a href="/admob-manager/pages/apps.php" class="nav-item <?php echo basename($_SERVER['PHP_SELF']) == 'apps.php' ? 'active' : ''; ?>">
            <i class="fas fa-mobile-alt"></i>
            <span>Apps</span>
        </a>
        
        <a href="/admob-manager/pages/ad-units.php" class="nav-item <?php echo basename($_SERVER['PHP_SELF']) == 'ad-units.php' ? 'active' : ''; ?>">
            <i class="fas fa-ad"></i>
            <span>Ad Units</span>
        </a>
        
        <a href="/admob-manager/pages/reports.php" class="nav-item <?php echo basename($_SERVER['PHP_SELF']) == 'reports.php' ? 'active' : ''; ?>">
            <i class="fas fa-file-alt"></i>
            <span>Reports</span>
        </a>
        
        <a href="/admob-manager/pages/analytics.php" class="nav-item <?php echo basename($_SERVER['PHP_SELF']) == 'analytics.php' ? 'active' : ''; ?>">
            <i class="fas fa-chart-bar"></i>
            <span>Analytics</span>
        </a>
        
        <a href="/admob-manager/pages/settings.php" class="nav-item <?php echo basename($_SERVER['PHP_SELF']) == 'settings.php' ? 'active' : ''; ?>">
            <i class="fas fa-cog"></i>
            <span>Settings</span>
        </a>
    </nav>
    
    <div class="sidebar-footer">
        <a href="/admob-manager/logout.php" class="nav-item logout">
            <i class="fas fa-sign-out-alt"></i>
            <span>Logout</span>
        </a>
    </div>
</aside>